@@ -1,23 +1,12 @@
 # -*- coding: utf-8 -*-
 """
-    Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-    partially based on C++ code from:
-    Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
+partially based on C++ code from:
+Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
 
-    Libkmahjongg is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 from qt import Qt, QSize
@@ -25,6 +14,7 @@ from qt import QWidget, QHBoxLayout, QVBoxLayout, \
     QPushButton, QSpacerItem, QSizePolicy, \
     QTreeView, QFont, QAbstractItemView, QHeaderView
 from qt import QModelIndex
+from kdestub import KApplication
 from rule import Ruleset, PredefinedRuleset, RuleBase, ParameterRule, BoolRule
 from util import uniqueList
 from mi18n import i18n, i18nc, i18ncE, english
@@ -56,11 +46,10 @@ class RuleTreeItem(TreeItem):
         """can be different for every rule"""
         if hasattr(self, 'colCount'):
             return self.colCount  # pylint: disable=no-member
-        else:
-            return len(self.rawContent)
+        return len(self.rawContent)
 
     def ruleset(self):
-        """returns the ruleset containing this item"""
+        """return the ruleset containing this item"""
         item = self
         while not isinstance(item.rawContent, Ruleset):
             item = item.parent
@@ -125,14 +114,13 @@ class RuleItem(RuleTreeItem):
         content = self.rawContent
         if column == 0:
             return content.name
+        if isinstance(content, ParameterRule):
+            if column == 1:
+                return content.parameter
         else:
-            if isinstance(content, ParameterRule):
-                if column == 1:
-                    return content.parameter
-            else:
-                if not hasattr(content.score, str(column)):
-                    column = colNames[column]
-                return getattr(content.score, column)
+            if not hasattr(content.score, str(column)):
+                column = colNames[column]
+            return getattr(content.score, column)
         return ''
 
     def tooltip(self):
@@ -141,8 +129,7 @@ class RuleItem(RuleTreeItem):
         if self.rawContent.description:
             return '<b>' + i18n(ruleset.name) + '</b><br><br>' + \
                 i18n(self.rawContent.description)
-        else:
-            return i18n(ruleset.name)
+        return i18n(ruleset.name)
 
 
 class RuleModel(TreeModel):
@@ -150,7 +137,7 @@ class RuleModel(TreeModel):
     """a model for our rule table"""
 
     def __init__(self, rulesets, title, parent=None):
-        super(RuleModel, self).__init__(parent)
+        super().__init__(parent)
         self.rulesets = rulesets
         self.loaded = False
         unitNames = list()
@@ -164,12 +151,12 @@ class RuleModel(TreeModel):
         rootData.extend(unitNames)
         self.rootItem = RuleRootItem(rootData)
 
-    def canFetchMore(self, dummyParent=None):
+    def canFetchMore(self, unusedParent=None):
         """did we already load the rules? We only want to do that
         when the config tab with rulesets is actually shown"""
         return not self.loaded
 
-    def fetchMore(self, dummyParent=None):
+    def fetchMore(self, unusedParent=None):
         """load the rules"""
         for ruleset in self.rulesets:
             self.appendRuleset(ruleset)
@@ -177,7 +164,7 @@ class RuleModel(TreeModel):
 
     def data(self, index, role):  # pylint: disable=no-self-use
         """get data fom model"""
-        # pylint: disable=too-many-branches,redefined-variable-type
+        # pylint: disable=too-many-branches
         # too many branches
         result = None
         if index.isValid():
@@ -227,18 +214,18 @@ class RuleModel(TreeModel):
         """tell the view about the wanted headers"""
         if Qt is None:
             # happens when kajongg exits unexpectedly
-            return
+            return None
         if role == Qt.DisplayRole and orientation == Qt.Horizontal:
             if section >= self.rootItem.columnCount():
-                return
+                return None
             result = self.rootItem.content(section)
             if result == 'doubles':
                 return 'x2'
-            else:
-                return i18nc('kajongg', result)
-        elif role == Qt.TextAlignmentRole:
+            return i18nc('kajongg', result)
+        if role == Qt.TextAlignmentRole:
             leftRight = Qt.AlignLeft if section == 0 else Qt.AlignRight
             return int(leftRight | Qt.AlignVCenter)
+        return None
 
     def appendRuleset(self, ruleset):
         """append ruleset to the model"""
@@ -250,15 +237,14 @@ class RuleModel(TreeModel):
         rulesetItems = list([RulesetItem(ruleset)])
         self.insertRows(row, rulesetItems, parent)
         rulesetIndex = self.index(row, 0, parent)
-        ruleLists = list(x for x in ruleset.ruleLists if len(x))
-        ruleListItems = list([RuleListItem(x) for x in ruleLists])
+        ruleLists = [x for x in ruleset.ruleLists if len(x)]
+        ruleListItems = [RuleListItem(x) for x in ruleLists]
         for item in ruleListItems:
             item.colCount = self.rootItem.columnCount()
         self.insertRows(0, ruleListItems, rulesetIndex)
         for ridx, ruleList in enumerate(ruleLists):
             listIndex = self.index(ridx, 0, rulesetIndex)
-            ruleItems = list([RuleItem(x)
-                              for x in ruleList if 'internal' not in x.options])
+            ruleItems = [RuleItem(x) for x in ruleList if 'internal' not in x.options]
             self.insertRows(0, ruleItems, listIndex)
 
 
@@ -280,10 +266,9 @@ class EditableRuleModel(RuleModel):
             oldParameter = content.parameter
             if isinstance(content, BoolRule):
                 return False, ''
-            else:
-                if content.parameter != value:
-                    dirty = True
-                    content.parameter = value
+            if content.parameter != value:
+                dirty = True
+                content.parameter = value
             message = content.validate()
             if message:
                 content.parameter = oldParameter
@@ -298,40 +283,37 @@ class EditableRuleModel(RuleModel):
         # pylint:  disable=too-many-branches
         if not index.isValid():
             return False
-        try:
-            dirty = False
-            column = index.column()
-            item = index.internalPointer()
-            ruleset = item.ruleset()
-            content = item.rawContent
-            if role == Qt.EditRole:
-                if isinstance(content, Ruleset) and column == 0:
-                    oldName = content.name
-                    content.rename(english(value))
-                    dirty = oldName != content.name
-                elif isinstance(content, RuleBase):
-                    dirty, message = self.__setRuleData(column, content, value)
-                    if message:
-                        Sorry(message)
-                        return False
-                else:
+        dirty = False
+        column = index.column()
+        item = index.internalPointer()
+        ruleset = item.ruleset()
+        content = item.rawContent
+        if role == Qt.EditRole:
+            if isinstance(content, Ruleset) and column == 0:
+                oldName = content.name
+                content.rename(english(value))
+                dirty = oldName != content.name
+            elif isinstance(content, RuleBase):
+                dirty, message = self.__setRuleData(column, content, value)
+                if message:
+                    Sorry(message)
                     return False
-            elif role == Qt.CheckStateRole:
-                if isinstance(content, BoolRule) and column == 1:
-                    if not isinstance(ruleset, PredefinedRuleset):
-                        newValue = value == Qt.Checked
-                        if content.parameter != newValue:
-                            dirty = True
-                            content.parameter = newValue
-                else:
-                    return False
-            if dirty:
-                if isinstance(content, RuleBase):
-                    ruleset.updateRule(content)
-                self.dataChanged.emit(index, index)
-            return True
-        except BaseException:
-            return False
+            else:
+                return False
+        elif role == Qt.CheckStateRole:
+            if isinstance(content, BoolRule) and column == 1:
+                if not isinstance(ruleset, PredefinedRuleset):
+                    newValue = value == Qt.Checked
+                    if content.parameter != newValue:
+                        dirty = True
+                        content.parameter = newValue
+            else:
+                return False
+        if dirty:
+            if isinstance(content, RuleBase):
+                ruleset.updateRule(content)
+            self.dataChanged.emit(index, index)
+        return True
 
     def flags(self, index):  # pylint: disable=no-self-use
         """tell the view what it can do with this item"""
@@ -379,8 +361,8 @@ class RuleTreeView(QTreeView):
         self.rulesets = []  # nasty: this generates self.ruleModel
         self.differs = []
 
-    def dataChanged(self, dummyIndex1, dummyIndex2, dummyRoles=None):
-        """gets called if the model has changed: Update all differs"""
+    def dataChanged(self, unusedIndex1, unusedIndex2, unusedRoles=None):
+        """get called if the model has changed: Update all differs"""
         for differ in self.differs:
             differ.rulesetChanged()
 
@@ -396,7 +378,7 @@ class RuleTreeView(QTreeView):
             if self.btnRemove and self.btnCopy:
                 self.ruleModel = EditableRuleModel(rulesets, self.name)
             else:
-                self.ruleModel = RuleModel(rulesets, self.name) # pylint: disable=redefined-variable-type
+                self.ruleModel = RuleModel(rulesets, self.name)
             self.setItemDelegateForColumn(
                 1,
                 RightAlignedCheckboxDelegate(
@@ -409,7 +391,7 @@ class RuleTreeView(QTreeView):
                 self.ruleModelTest = ModelTest(self.ruleModel, self)
             self.show()
 
-    def selectionChanged(self, selected, dummyDeselected=None):
+    def selectionChanged(self, selected, unusedDeselected=None):
         """update editing buttons"""
         enableCopy = enableRemove = enableCompare = False
         if selected.indexes():
@@ -428,7 +410,7 @@ class RuleTreeView(QTreeView):
         if self.btnCompare:
             self.btnCompare.setEnabled(enableCompare)
 
-    def showEvent(self, dummyEvent):
+    def showEvent(self, unusedEvent):
         """reload the models when the view comes into sight"""
         # default: make sure the name column is wide enough
         if self.ruleModel.canFetchMore():
@@ -444,10 +426,9 @@ class RuleTreeView(QTreeView):
             self.resizeColumnToContents(col)
 
     def selectedRow(self):
-        """returns the currently selected row index (with column 0)"""
+        """return the currently selected row index (with column 0)"""
         rows = self.selectionModel().selectedRows()
-        if len(rows) == 1:
-            return rows[0]
+        return rows[0] if len(rows) == 1 else None
 
     def copyRow(self):
         """copy a ruleset"""
@@ -487,7 +468,7 @@ class RulesetSelector(QWidget):
     """presents all available rulesets with previews"""
 
     def __init__(self, parent=None):
-        super(RulesetSelector, self).__init__(parent)
+        super().__init__(parent)
         self.setContentsMargins(0, 0, 0, 0)
         self.setupUi()
 
@@ -540,7 +521,7 @@ class RulesetSelector(QWidget):
         """we never want a horizontal scrollbar for player names,
         we always want to see them in full"""
         result = QWidget.sizeHint(self)
-        available = Internal.app.desktop().availableGeometry()
+        available = KApplication.desktopSize()
         height = max(result.height(), available.height() * 2 // 3)
         width = max(result.width(), available.width() // 2)
         return QSize(width, height)
@@ -550,7 +531,7 @@ class RulesetSelector(QWidget):
         we always want to see them in full"""
         return self.sizeHint()
 
-    def showEvent(self, dummyEvent):
+    def showEvent(self, unusedEvent):
         """reload the rulesets"""
         self.refresh()
 
