@@ -1,22 +1,10 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 The DBPasswordChecker is based on an example from the book
 Twisted Network Programming Essentials by Abe Fettig, 2006
@@ -28,12 +16,13 @@ import datetime
 from twisted.internet.defer import fail
 from twisted.spread import pb
 
-from common import Internal, Debug, Options, nativeString
+from common import Internal, Debug, Options, StrMixin
 from servercommon import srvError
-from log import logDebug, m18nE
+from log import logDebug
+from mi18n import i18nE
 from query import Query
 
-class User(pb.Avatar):
+class User(pb.Avatar, StrMixin):
 
     """the twisted avatar"""
 
@@ -53,6 +42,8 @@ class User(pb.Avatar):
     def pinged(self):
         """time of last ping or message from user"""
         self.lastPing = datetime.datetime.now()
+        if self.server:
+            self.server.lastPing = self.lastPing
 
     def source(self):
         """how did he connect?"""
@@ -67,11 +58,11 @@ class User(pb.Avatar):
         self.mind = mind
         self.server.login(self)
 
-    def detached(self, dummyMind):
+    def detached(self, unusedMind):
         """override pb.Avatar.detached"""
         if Debug.connections:
             logDebug(
-                u'%s: connection detached from %s' %
+                '%s: connection detached from %s' %
                 (self, self.source()))
         self.server.logout(self)
         self.mind = None
@@ -79,34 +70,34 @@ class User(pb.Avatar):
     def perspective_setClientProperties(
             self, dbIdent, voiceId, maxGameId, clientVersion=None):
         """perspective_* methods are to be called remotely"""
+        self.pinged()
         self.dbIdent = dbIdent
         self.voiceId = voiceId
         self.maxGameId = maxGameId
-        clientVersion = nativeString(clientVersion)
-        serverVersion = Internal.defaultPort
+        serverVersion = str(Internal.defaultPort)
         if clientVersion != serverVersion:
             # we assume that versions x.y.* are compatible
             if clientVersion is None:
                 # client passed no version info
                 return fail(srvError(pb.Error,
-                                     m18nE(
+                                     i18nE(
                                          'Your client has a version older than 4.9.0 but you need %1 for this server'),
                                      serverVersion))
-            else:
-                commonDigits = len([x for x in zip(
-                    clientVersion.split(b'.'),
-                    serverVersion.split(b'.'))
-                                    if x[0] == x[1]])
-                if commonDigits < 2:
-                    return fail(srvError(pb.Error,
-                                         m18nE(
-                                             'Your client has version %1 but you need %2 for this server'),
-                                         clientVersion or '<4.9.0',
-                                         '.'.join(serverVersion.split('.')[:2]) + '.*'))
+            commonDigits = len([x for x in zip(
+                clientVersion.split('.'),
+                serverVersion.split('.'))
+                                if x[0] == x[1]])
+            if commonDigits < 2:
+                return fail(srvError(pb.Error,
+                                     i18nE(
+                                         'Your client has version %1 but you need %2 for this server'),
+                                     clientVersion or '<4.9.0',
+                                     '.'.join(serverVersion.split('.')[:2]) + '.*'))
         if Debug.table:
-            logDebug(u'client has dbIdent={} voiceId={} maxGameId={} clientVersion {}'.format(
+            logDebug('client has dbIdent={} voiceId={} maxGameId={} clientVersion {}'.format(
                 self.dbIdent, self.voiceId, self.maxGameId, clientVersion))
         self.server.sendTables(self)
+        return None
 
     def perspective_ping(self):
         """perspective_* methods are to be called remotely"""
@@ -122,12 +113,11 @@ class User(pb.Avatar):
 
     def perspective_leaveTable(self, tableid):
         """perspective_* methods are to be called remotely"""
-        return self.server.leaveTable(self, tableid)
+        return self.server.leaveTable(self, tableid, None)
 
     def perspective_newTable(
-            self, ruleset, playOpen, autoPlay, wantedGame, tableId=None):
+            self, ruleset, playOpen, autoPlay, wantedGame: str, tableId=None):
         """perspective_* methods are to be called remotely"""
-        wantedGame = nativeString(wantedGame)
         return self.server.newTable(self, ruleset, playOpen, autoPlay, wantedGame, tableId)
 
     def perspective_startGame(self, tableid):
@@ -140,9 +130,8 @@ class User(pb.Avatar):
 
     def perspective_chat(self, chatString):
         """perspective_* methods are to be called remotely"""
+        self.pinged()
         return self.server.chat(chatString)
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
-
-
